@@ -9,7 +9,7 @@ misc_size_t (*misc_partitionRange)(const misc_xint_t* restrict x, misc_xint_t cu
 misc_size_t (*misc_partitionIndices)(const misc_xint_t* restrict x, misc_xint_t cut, misc_size_t* restrict indices, misc_size_t length) = 0;
 
 #define PARTITION_RANGE 1
-size_t misc_partitionRange_c(misc_xint_t* restrict x, misc_xint_t cut, size_t* restrict indices, size_t length)
+size_t misc_partitionRange_c(const misc_xint_t* restrict x, misc_xint_t cut, size_t* restrict indices, size_t length)
 {
 #include "partition_body.c"
 }
@@ -17,7 +17,7 @@ size_t misc_partitionRange_c(misc_xint_t* restrict x, misc_xint_t cut, size_t* r
 #undef PARTITION_RANGE
 #define PARTITION_RANGE 0
 
-size_t misc_partitionIndices_c(misc_xint_t* restrict x, misc_xint_t cut, size_t* restrict indices, size_t length)
+size_t misc_partitionIndices_c(const misc_xint_t* restrict x, misc_xint_t cut, size_t* restrict indices, size_t length)
 {
 #include "partition_body.c"
 }
